<?php
/**
 * @file
 *   EMMi integration related drush commands.
 */

/**
 * Implements hook_drush_command().
 *
 * @see drush_parse_command()
 *   For a list of recognized keys.
 *
 * @return
 *   An associative array describing your command(s).
 */
function itella_emmi_drush_command() {
  $items = array();

  $items['itella-emmi-test'] = array(
    'description' => "Test Itella EMMi interface",
    'aliases' => array("iet"),
  );

  $items['itella-emmi-search'] = array(
    'description' => "Search for STUFF",
    'arguments' => array(
      'words' => 'searchwords (multiple in quotes)',
      'type' => 'Search type: contains, words, exactly, begins, ends, lucene',
    ),
    'aliases' => array("ies"),
  );

  return $items;
}

/**
 * Callback method for drush command 'itella-emmi-test'.
 */
function drush_itella_emmi_test($arg = NULL, $exact = TRUE) {

  $emmi = itella_emmi_instance();
  $emmi->report();

}

/**
 * Callback method for drush command 'itella-emmi-search'.
 */
function drush_itella_emmi_search($arg1, $arg2 = NULL) {

  $emmi = itella_emmi_instance();

  if ($arg2 == NULL) {
    $type = "exactly";
    $words = $arg1;
  }
  else {
    $type = $arg1;
    $words = $arg2;
  }

  $criterias = array();

  // Require keyword
  if (empty($words)) {
    drupal_set_message(t("Give me something to look for.", array("@arg" => $exact)), "error");
    return;
  }

  // Validate type
  $types = array(
    "contains" => ItellaEmmiSearchCriteria::STRING_OPTION_CONTAINS,
    "words" => ItellaEmmiSearchCriteria::STRING_OPTION_WORDS,
    "exactly" => ItellaEmmiSearchCriteria::STRING_OPTION_EXACTLY,
    "begins" => ItellaEmmiSearchCriteria::STRING_OPTION_BEGINS,
    "ends" => ItellaEmmiSearchCriteria::STRING_OPTION_ENDS,
    "lucene" => ItellaEmmiSearchCriteria::STRING_OPTION_LUCENE,
  );
  if (!isset($types[$type])) {
    drupal_set_message(t("Illegal argument: @arg", array("@arg" => $type)), "error");
    return;
  }

  $criterias[] = new ItellaEmmiSearchCriteriaKeyword($words, NULL, $types[$type]);
  $files = $emmi->searchFiles($criterias);

  if ($files) {
    print_r($files);
  }
  else {
    print("No matches.\n");
  }

}
